@@ -71,7 +71,7 @@ def createbot(name):
         f_dest.write(f_source.read())
 
     """README"""
-    with open(os.path.join(template,'README.md'),'r') as f_source,open(os.path.join(path,name,'README.md'),'w') as f_dest:
-        f_dest.write(f_source.read())
+    with open(os.path.join(template,'README.py'),'r') as f_source,open(os.path.join(path,name,'README.md'),'w') as f_dest:
+        f_dest.write('\n'.join(f_source.read().split('\n')[1:-1]))
     
     click.echo(f"\n\u001b[32mSuccessfully created '{name}' in the current directory\u001b[0m\n")
\ No newline at end of file
